SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL';

DROP SCHEMA IF EXISTS `exafarm` ;
CREATE SCHEMA IF NOT EXISTS `exafarm` DEFAULT CHARACTER SET utf8 COLLATE utf8_spanish_ci ;
USE `exafarm` ;

-- -----------------------------------------------------
-- Table `exafarm`.`grupos`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `exafarm`.`grupos` ;

CREATE  TABLE IF NOT EXISTS `exafarm`.`grupos` (
  `id_grupo` VARCHAR(15) NOT NULL ,
  `descripcion` VARCHAR(45) NULL ,
  PRIMARY KEY (`id_grupo`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `exafarm`.`usuarios`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `exafarm`.`usuarios` ;

CREATE  TABLE IF NOT EXISTS `exafarm`.`usuarios` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `user_id` VARCHAR(45) NULL ,
  `password` VARCHAR(50) NULL ,
  `nombre` VARCHAR(45) NULL ,
  `apellidos` VARCHAR(45) NULL ,
  `email` VARCHAR(45) NULL ,
  `is_activo` TINYINT NULL ,
  `grupo` VARCHAR(15) NULL ,
  `last_login` DATETIME NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `NDX_userid` (`user_id` ASC) ,
  INDEX `FK_grupo` (`grupo` ASC) ,
  CONSTRAINT `FK_grupo`
    FOREIGN KEY (`grupo` )
    REFERENCES `exafarm`.`grupos` (`id_grupo` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB, 
COMMENT = 'Datos de usuario' ;


-- -----------------------------------------------------
-- Table `exafarm`.`examenes`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `exafarm`.`examenes` ;

CREATE  TABLE IF NOT EXISTS `exafarm`.`examenes` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `fecha_convocatoria` DATE NULL ,
  `num_preguntas` INT NULL ,
  `num_versiones` INT NULL ,
  `is_activo` TINYINT(1) NULL ,
  `is_cerrado` TINYINT(1) NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `exafarm`.`bloques`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `exafarm`.`bloques` ;

CREATE  TABLE IF NOT EXISTS `exafarm`.`bloques` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `descripcion` VARCHAR(45) NULL ,
  `is_activo` TINYINT(1) NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `exafarm`.`temas`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `exafarm`.`temas` ;

CREATE  TABLE IF NOT EXISTS `exafarm`.`temas` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `descripcion` VARCHAR(300) NULL ,
  `descripcion_corta` VARCHAR(45) NULL ,
  `id_bloque` INT NULL ,
  `is_activo` TINYINT(1) NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `FK_bloques` (`id_bloque` ASC) ,
  CONSTRAINT `FK_bloques`
    FOREIGN KEY (`id_bloque` )
    REFERENCES `exafarm`.`bloques` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `exafarm`.`preguntas`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `exafarm`.`preguntas` ;

CREATE  TABLE IF NOT EXISTS `exafarm`.`preguntas` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `is_activa` TINYINT NULL ,
  `fecha_creacion` DATE NULL ,
  `id_tema` INT NULL ,
  `texto` VARCHAR(500) NULL ,
  `is_corta` TINYINT(1) NULL ,
  `id_usuario` INT NULL ,
  `is_mezclable` TINYINT(1) NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `FK_usuario` (`id_usuario` ASC) ,
  INDEX `FK_tema` (`id_tema` ASC) ,
  CONSTRAINT `FK_usuario`
    FOREIGN KEY (`id_usuario` )
    REFERENCES `exafarm`.`usuarios` (`id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `FK_tema`
    FOREIGN KEY (`id_tema` )
    REFERENCES `exafarm`.`temas` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `exafarm`.`respuestas`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `exafarm`.`respuestas` ;

CREATE  TABLE IF NOT EXISTS `exafarm`.`respuestas` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `id_pregunta` INT NULL ,
  `texto` VARCHAR(500) NULL ,
  `is_correcta` TINYINT(1) NULL ,
  `is_activa` TINYINT(1) NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `FK_preguntas` (`id_pregunta` ASC) ,
  CONSTRAINT `FK_preguntas`
    FOREIGN KEY (`id_pregunta` )
    REFERENCES `exafarm`.`preguntas` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `exafarm`.`examen_pregunta`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `exafarm`.`examen_pregunta` ;

CREATE  TABLE IF NOT EXISTS `exafarm`.`examen_pregunta` (
  `id_examen` INT NOT NULL ,
  `id_pregunta` INT NOT NULL ,
  PRIMARY KEY (`id_examen`, `id_pregunta`) ,
  INDEX `NDX_pregunta_examen` (`id_pregunta` ASC, `id_examen` ASC) ,
  INDEX `FK_examen` (`id_examen` ASC) ,
  INDEX `FK_pregunta` (`id_pregunta` ASC) ,
  CONSTRAINT `FK_examen`
    FOREIGN KEY (`id_examen` )
    REFERENCES `exafarm`.`examenes` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `FK_pregunta`
    FOREIGN KEY (`id_pregunta` )
    REFERENCES `exafarm`.`preguntas` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;
